==> fluxbb-1.4.2p0.tgz: fluxbb/lang/English/misc.php <==
<?php

// Language definitions used in various scripts
$lang_misc = array(

'Mark read redirect'			=>	'All topics and forums have been marked as read. Redirecting …',
'Mark forum read redirect'		=>	'All topics in the specified forum have been marked as read. Redirecting …',

// Send email
'Form email disabled'			=>	'The user you are trying to send an email to has disabled form email.',
'No email subject'				=>	'You must enter a subject.',
'No email message'				=>	'You must enter a message.',
'Too long email message'		=>	'Messages cannot be longer than 65535 characters (64 KB).',
'Email flood'					=>	'At least %s seconds have to pass between sent emails. Please wait a while and try sending again.',
'Email sent redirect'			=>	'Email sent. Redirecting …',
'Send email to'					=>	'Send email to',
'Email subject'					=>	'Subject',
'Email message'					=>	'Message',
'Email disclosure note'			=>	'Please note that by using this form, your email address will be disclosed to the recipient.',
'Write email'					=>	'Write and submit your email message',

// Report
'No reason'						=>	'You must enter a reason.',
'Reason too long'				=>	'Your message must be under 65535 bytes (~64kb).',
'Report flood'					=>	'At least %s seconds have to pass between reports. Please wait a while and try sending again.',
'Report redirect'				=>	'Post reported. Redirecting …',
'Report post'					=>	'Report post',
'Reason'						=>	'Reason',
'Reason desc'					=>	'Please enter a short reason why you are reporting this post',

// Subscriptions
'Already subscribed'			=>	'You are already subscribed to this topic.',
'Subscribe redirect'			=>	'Your subscription has been added. Redirecting …',
'Not subscribed'				=>	'You are not subscribed to this topic.',
'Unsubscribe redirect'			=>	'Your subscription has been removed. Redirecting …',

// General forum and topic moderation
'Moderate'						=>	'Moderate',
'Select'						=>	'Select', // the header of a column of checkboxes
'Move'							=>	'Move',
'Split'							=>	'Split',
'Delete'						=>	'Delete',
'Merge'							=>	'Merge',

// Moderate forum
'Open'							=>	'Open',
'Close'							=>	'Close',
'Move topic'					=>	'Move topic',
'Move topics'					=>	'Move topics',
'Move legend'					=>	'Select destination of move',
'Move to'						=>	'Move to',
'Nowhere to move'				=>	'There are no forums into which you can move topics.',
'Leave redirect'				=>	'Leave redirect topic(s)',
'Move topic redirect'			=>	'Topic moved. Redirecting …',
'Move topics redirect'			=>	'Topics moved. Redirecting …',
'Confirm delete legend'			=>	'Please confirm deletion',
'Delete topics'					=>	'Delete topics',
'Delete topics comply'			=>	'Are you sure you want to delete the selected topics?',
'Delete topics redirect'		=>	'Topics deleted. Redirecting …',
'Open topic redirect'			=>	'Topic opened. Redirecting …',
'Open topics redirect'			=>	'Topics opened. Redirecting …',
'Close topic redirect'			=>	'Topic closed. Redirecting …',
'Close topics redirect'			=>	'Topics closed. Redirecting …',
'No topics selected'			=>	'You must select at least one topic for move/delete/open/close.',
'Not enough topics selected'	=>	'You must select at least two topics for merge.',
'Stick topic redirect'			=>	'Topic sticked. Redirecting …',
'Unstick topic redirect'		=>	'Topic unsticked. Redirecting …',
'Merge topics'					=>	'Merge topics',
'Merge topics redirect'			=>	'Topics merged. Redirecting …',
'Confirm merge legend'			=>	'Please confirm merge',
'New subject'					=>	'New subject',

// Split multiple posts in topic
'Confirm split legend'			=>	'Please confirm split of selected posts.',
'Split posts'					=>	'Split posts',
'Split posts comply'			=>	'Are you sure you want to split the selected posts?',
'Split posts redirect'			=>	'Posts have been split. Redirecting …',

// Delete multiple posts in topic
'Delete posts'					=>	'Delete posts',
'Cannot select first'			=>	'First post cannot be selected for split/delete.',
'Delete posts comply'			=>	'Are you sure you want to delete the selected posts?',
'Delete posts redirect'			=>	'Posts deleted. Redirecting …',
'No posts selected'				=>	'You must select at least one post for split/delete.',

// Get host
'Host info 1'					=>	'The IP address is: %s',
'Host info 2'					=>	'The host name is: %s',
'Show more users'				=>	'Show more users for this IP',

);

==> fluxbb-1.5.0p0.tgz: fluxbb/lang/English/misc.php <==
<?php

// Language definitions used in various scripts
$lang_misc = array(

'Mark read redirect'			=>	'All topics and forums have been marked as read. Redirecting …',
'Mark forum read redirect'		=>	'All topics in the specified forum have been marked as read. Redirecting …',

// Send email
'Form email disabled'			=>	'The user you are trying to send an email to has disabled form email.',
'No email subject'				=>	'You must enter a subject.',
'No email message'				=>	'You must enter a message.',
'Too long email message'		=>	'Messages cannot be longer than 65535 characters (64 KB).',
'Email flood'					=>	'At least %s seconds have to pass between sent emails. Please wait a while and try sending again.',
'Email sent redirect'			=>	'Email sent. Redirecting …',
'Send email to'					=>	'Send email to',
'Email subject'					=>	'Subject',
'Email message'					=>	'Message',
'Email disclosure note'			=>	'Please note that by using this form, your email address will be disclosed to the recipient.',
'Write email'					=>	'Write and submit your email message',

// Report
'No reason'						=>	'You must enter a reason.',
'Reason too long'				=>	'Your message must be under 65535 bytes (~64kb).',
'Report flood'					=>	'At least %s seconds have to pass between reports. Please wait a while and try sending again.',
'Report redirect'				=>	'Post reported. Redirecting …',
'Report post'					=>	'Report post',
'Reason'						=>	'Reason',
'Reason desc'					=>	'Please enter a short reason why you are reporting this post',

// Subscriptions
'Already subscribed topic'		=>	'You are already subscribed to this topic.',
'Already subscribed forum'		=>	'You are already subscribed to this forum.',
'Subscribe redirect'			=>	'Your subscription has been added. Redirecting …',
'Not subscribed topic'			=>	'You are not subscribed to this topic.',
'Not subscribed forum'			=>	'You are not subscribed to this forum.',
'Unsubscribe redirect'			=>	'Your subscription has been removed. Redirecting …',

// General forum and topic moderation
'Moderate'						=>	'Moderate',
'Select'						=>	'Select', // the header of a column of checkboxes
'Move'							=>	'Move',
'Split'							=>	'Split',
'Delete'						=>	'Delete',
'Merge'							=>	'Merge',

// Moderate forum
'Open'							=>	'Open',
'Close'							=>	'Close',
'Move topic'					=>	'Move topic',
'Move topics'					=>	'Move topics',
'Move legend'					=>	'Select destination of move',
'Move to'						=>	'Move to',
'Nowhere to move'				=>	'There are no forums into which you can move topics.',
'Leave redirect'				=>	'Leave redirect topic(s)',
'Move topic redirect'			=>	'Topic moved. Redirecting …',
'Move topics redirect'			=>	'Topics moved. Redirecting …',
'Confirm delete legend'			=>	'Please confirm deletion',
'Delete topics'					=>	'Delete topics',
'Delete topics comply'			=>	'Are you sure you want to delete the selected topics?',
'Delete topics redirect'		=>	'Topics deleted. Redirecting …',
'Open topic redirect'			=>	'Topic opened. Redirecting …',
'Open topics redirect'			=>	'Topics opened. Redirecting …',
'Close topic redirect'			=>	'Topic closed. Redirecting …',
'Close topics redirect'			=>	'Topics closed. Redirecting …',
'No topics selected'			=>	'You must select at least one topic for move/delete/open/close.',
'Not enough topics selected'	=>	'You must select at least two topics for merge.',
'Stick topic redirect'			=>	'Topic sticked. Redirecting …',
'Unstick topic redirect'		=>	'Topic unsticked. Redirecting …',
'Merge topics'					=>	'Merge topics',
'Merge topics redirect'			=>	'Topics merged. Redirecting …',
'Confirm merge legend'			=>	'Please confirm merge',
'New subject'					=>	'New subject',

// Split multiple posts in topic
'Confirm split legend'			=>	'Please confirm split of selected posts and select destination of move.',
'Split posts'					=>	'Split posts',
'Split posts comply'			=>	'Are you sure you want to split the selected posts?',
'Split posts redirect'			=>	'Posts have been split. Redirecting …',

// Delete multiple posts in topic
'Delete posts'					=>	'Delete posts',
'Cannot select first'			=>	'First post cannot be selected for split/delete.',
'Delete posts comply'			=>	'Are you sure you want to delete the selected posts?',
'Delete posts redirect'			=>	'Posts deleted. Redirecting …',
'No posts selected'				=>	'You must select at least one post for split/delete.',

// Get host
'Host info 1'					=>	'The IP address is: %s',
'Host info 2'					=>	'The host name is: %s',
'Show more users'				=>	'Show more users for this IP',

);
